@@ -1,7 +1,7 @@
 package Perinci::Sub::To::POD;
 
-our $DATE = '2016-03-02'; # DATE
-our $VERSION = '0.77'; # VERSION
+our $DATE = '2016-04-18'; # DATE
+our $VERSION = '0.78'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -203,7 +203,8 @@ sub after_gen_doc {
         }
         my @summary_lines;
         {
-            my $summary = $eg->{summary} // "Example #$i";
+            my $summary = $eg->{summary} //
+                "Example #$i".(defined($eg->{name}) ? " ($eg->{name})" :"");
             push @summary_lines, ("=item * $summary" . ":", "");
         }
 
@@ -376,19 +377,23 @@ that contains extra information.")), "")
     $self->add_doc_lines("", $self->_md2pod($dres->{res_description}), "")
         if $dres->{res_description};
 
-    if ($meta->{links} && @{ $meta->{links} }) {
-        $self->add_doc_lines(__("See also") . ":", "", "=over", "");
-        for my $link (@{ $meta->{links} }) {
-            my $url = $link->{url};
-            # currently only handles pm: urls (link to another perl module)
-            next unless $url =~ m!\Apm:(.+)!;
-            my $mod = $1;
-            $self->add_doc_lines("* L<$mod>", "");
-            $self->add_doc_lines($link->{summary}.".", "") if $link->{summary};
-            $self->add_doc_lines($self->_md2pod($link->{description}), "") if $link->{description};
-        }
-        $self->add_doc_lines("=back", "");
-    }
+    # we only show See Also on a per-package basis
+    #
+    #if ($meta->{links} && @{ $meta->{links} }) {
+    #    $self->add_doc_lines(__("See also") . ":", "", "=over", "");
+    #    for my $link (@{ $meta->{links} }) {
+    #        my $url = $link->{url};
+    #        if ($url =~ m!\Apm:(.+)!) {
+    #            my $mod = $1;
+    #            $self->add_doc_lines("* L<$mod>", "");
+    #        } else {
+    #            $self->add_doc_lines("* L<$url>", "");
+    #        }
+    #        $self->add_doc_lines($link->{summary}.".", "") if $link->{summary};
+    #        $self->add_doc_lines($self->_md2pod($link->{description}), "") if $link->{description};
+    #    }
+    #    $self->add_doc_lines("=back", "");
+    #}
 }
 
 1;
@@ -406,7 +411,7 @@ Perinci::Sub::To::POD - Generate POD documentation from Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.77 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2016-03-02.
+This document describes version 0.78 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2016-04-18.
 
 =head1 SYNOPSIS
 
@@ -424,7 +429,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-To
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-To-Doc>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-To-Doc>.
 
 =head1 BUGS
 
