@@ -1,7 +1,7 @@
 package Perinci::To::POD;
 
-our $DATE = '2016-03-02'; # DATE
-our $VERSION = '0.77'; # VERSION
+our $DATE = '2016-04-18'; # DATE
+our $VERSION = '0.78'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -123,19 +123,27 @@ sub gen_doc_section_functions {
 sub gen_doc_section_links {
     my $self = shift;
 
+    my %seen_urls;
     my $meta = $self->meta;
+    my $child_metas = $self->child_metas;
 
-    if ($meta->{links} && @{ $meta->{links} }) {
+    my @links;
+    push @links, @{ $meta->{links} } if $meta->{links};
+    for my $m (values %$child_metas) {
+        push @links, @{ $m->{links} } if $m->{links};
+    }
+
+    if (@links) {
         $self->add_doc_lines("=head1 " . __("SEE ALSO"), "");
-        for my $link (@{ $meta->{links} }) {
+        for my $link0 (@links) {
+            my $link = ref($link0) ? $link0 : {url=>$link0};
             my $url = $link->{url};
-            # currently only handles pm: urls (link to another perl module)
-            next unless $url =~ m!\Apm:(.+)!;
-            my $mod = $1;
+            next if $seen_urls{$url}++;
+            $url =~ s!\Apm:!!;
             $self->add_doc_lines(
-                "L<$mod>" .
+                "L<$url>" .
                     ($link->{summary} ? ", $link->{summary}." : "") .
-                    ($link->{summary} ? $self->_md2pod($link->{description}) : ""),
+                    ($link->{description} ? ". " . $self->_md2pod($link->{description}) : ""),
                 "");
         }
     }
@@ -156,7 +164,7 @@ Perinci::To::POD - Generate POD documentation for a package from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.77 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2016-03-02.
+This document describes version 0.78 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2016-04-18.
 
 =head1 SYNOPSIS
 
@@ -180,7 +188,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-To
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-To-Doc>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-To-Doc>.
 
 =head1 BUGS
 
